from enum import Enum


class Role(str, Enum):
    ADMIN = "ROLE_ADMIN",
    SERVICE = "ROLE_SERVICE",
    AI_TESTER = "ROLE_AI_TESTER",
    PRACTICE_ADMIN = "ROLE_PRACTICE_ADMIN",
    PRACTICE_OFFICE_ADMIN = "ROLE_PRACTICE_OFFICE_ADMIN",
    PRACTICE_DOCTOR = "ROLE_PRACTICE_DOCTOR",
    PRACTICE_SECRETARY = "ROLE_PRACTICE_SECRETARY",
